pub fn setup_trampoline_for_task_kstack_window(
task: &Task,
) -> Result<(), &'static str>Expand description
Map the task’s kernel stack physical pages into the shared kernel PT at a unique high VA window. Adds an unmapped guard page at the bottom of the window.