pub fn verify_task_kernel_stack_guard(task: &Task) -> boolExpand description
Verify that a task’s kernel stack guard page is unmapped and stack pages are mapped. Returns true if the guard page has no associated memory map and a sample stack address is mapped.